//
//  RootViewController.m
//  MultiDetailView
//
//  Created by Greg Fiumara on 3/24/10.
//  Copyright Greg Fiumara 2010. All rights reserved.
//

#import "RootViewController.h"


@implementation RootViewController

@synthesize splitViewController;
@synthesize rootPopoverBarButtonItem;
@synthesize popoverController;

#pragma mark -
#pragma mark SplitViewController Delegate methods

- (void)splitViewController:(UISplitViewController*)svc willHideViewController:(UIViewController *)aViewController withBarButtonItem:(UIBarButtonItem*)barButtonItem forPopoverController:(UIPopoverController*)pc 
{	
        // Setup the button that will display the popoverController
	barButtonItem.title = NSLocalizedString(@"Show UIPopoverController", nil);
	self.popoverController = pc;
	self.rootPopoverBarButtonItem = barButtonItem;
	
        // Assign the button to the current detail view
	UIViewController <SubstitutableDetailViewController> *detailViewController = [splitViewController.viewControllers objectAtIndex:1];
	[detailViewController showRootPopoverButtonItem:self.rootPopoverBarButtonItem];
}

- (void)splitViewController:(UISplitViewController*)svc willShowViewController:(UIViewController *)aViewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem 
{
        // Remove the button that displays the popoverController in the detailView
	UIViewController <SubstitutableDetailViewController> *detailViewController = [splitViewController.viewControllers objectAtIndex:1];
	[detailViewController invalidateRootPopoverButtonItem:self.rootPopoverBarButtonItem];
	self.popoverController = nil;
	self.rootPopoverBarButtonItem = nil;
}

#pragma mark -
#pragma mark View lifecycle

- (void)viewDidLoad 
{
	[super viewDidLoad];
	self.clearsSelectionOnViewWillAppear = NO;
	self.contentSizeForViewInPopover = CGSizeMake(320.0, 600.0);
}


- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation 
{
	return YES;
}

#pragma mark -
#pragma mark Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)aTableView 
{
	return 1;
}

- (NSInteger)tableView:(UITableView *)aTableView numberOfRowsInSection:(NSInteger)section 
{
	return 10;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath 
{
	
	static NSString *CellIdentifier = @"CellIdentifier";
	
	// Dequeue or create a cell of the appropriate type.
	UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
	if (cell == nil) {
		cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
		cell.accessoryType = UITableViewCellAccessoryNone;
	}
	
	// Configure the cell.
	if (indexPath.row % 2)
		cell.textLabel.text = [NSString stringWithFormat:@"SecondDetailVC", indexPath.row];
	else
		cell.textLabel.text = [NSString stringWithFormat:@"FirstDetailVC", indexPath.row];
	
	return cell;
}

#pragma mark -
#pragma mark Table view delegate

- (void)tableView:(UITableView *)aTableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath 
{
        /*
         * Here's where you want to be looking.  We're allocating a 
         * UIViewController that implements the 
         * SubstitutableDetailViewController protocol, meaning that it is of the
         * correct type to be placed as our detailView based on what we defined
         * in out ApplicationDelegate.
         */
	UIViewController <SubstitutableDetailViewController> *detailViewController = nil;
	
        /* 
         * Alternate what type of SubstitutableDetailViewController we should
         * use.  Insert your own code here to orchestrate whatever madness makes
         * sense for your application.
         */
	if (indexPath.row % 2)
		detailViewController = [[SecondDetailViewController alloc] init];
	else
		detailViewController = [[FirstDetailViewController alloc] init];
	
	
	// Update the split view controller's view controllers array.
	NSArray *viewControllers = [[NSArray alloc] initWithObjects:self.navigationController, detailViewController, nil];
	splitViewController.viewControllers = viewControllers;
	[viewControllers release];
	
	// Dismiss the popover if it's present.
	if (popoverController != nil)
		[popoverController dismissPopoverAnimated:YES];
	
	// Configure the new view controller's popover button (after the view has been displayed and its toolbar/navigation bar has been created).
	if (self.rootPopoverBarButtonItem != nil) {
		[detailViewController showRootPopoverButtonItem:self.rootPopoverBarButtonItem];
	}
	
	[detailViewController release];
}

#pragma mark -

- (void)dealloc 
{
	self.rootPopoverBarButtonItem = nil;
	self.popoverController = nil;
	self.splitViewController = nil;
	
	[super dealloc];
}


@end

